import React, {Component} from 'react';
import classNames from "classnames";
import Popover from "react-popover";

require("./popover.scss");


export default class ReactPopover extends Component {
    constructor(props, context) {
        super(props, context);
        this.state = {isOpen: false};
        this.setWrapperRef = this.setWrapperRef.bind(this);
        this.handleClickOutside = this.handleClickOutside.bind(this);
    }

    toggle(toState = null) {
        this.setState({isOpen: toState === null ? !this.state.isOpen : toState})
    }

    componentDidMount() {
        document.addEventListener('mousedown', this.handleClickOutside);
    }

    componentWillUnmount() {
        document.removeEventListener('mousedown', this.handleClickOutside);
    }

    /**
     * Set the wrapper ref
     */
    setWrapperRef(node) {
        this.wrapperRef = node;
    }

    /**
     * Alert if clicked on outside of element
     */
    handleClickOutside(event) {
        if (this.wrapperRef && !this.wrapperRef.contains(event.target)) {
            this.setState({isOpen: false})
        }
    }

    getTriggerProps(trigger) {
        const location = window.location;
        if (location.search.includes("click")) {
            return {onClick: ()=> this.toggle()};
        }
        switch (trigger) {
            case "mouseover": {
                return {
                    onMouseOver: () => this.toggle(true),
                    onMouseOut: () => this.toggle(false)
                }
            }
            case "mouseover-exit-click": {
                return {
                    onMouseOver: () => this.toggle(true),
                    onClick: () => this.toggle(false)
                }
            }
            default: {
                return {onClick: () => this.toggle()}
            }
        }
    };


    render() {
        const {isOpen} = this.state;
        const {container, popoverClass, contentStyle, children, preferPlace, containerClassName, trigger} = this.props;
        const triggerProps = this.getTriggerProps(trigger);
        const triggerElement = React.cloneElement(container, triggerProps);
        const popoverBody = (
            <div className="popover-container" ref={this.setWrapperRef}>
                <div className={classNames("react-popover", popoverClass)}>
                    <div className="popover-content" style={contentStyle}>
                        {children}
                    </div>
                </div>
            </div>
        );

        return (
            <Popover isOpen={isOpen} body={popoverBody} preferPlace={preferPlace ? preferPlace : "below"} className={popoverClass}>
            <span className={classNames("popover-trigger-container", {active: isOpen}, containerClassName)}>
                {triggerElement}
                </span>
            </Popover>

        );
    }
}

