import React, {Component} from 'react';
import {Query} from 'react-apollo'
import LoadingIcon from '../../../components/widgets/LoadingIcon'
import Subscribe from './Subscribe';
import {
    FREE_TRIAL_PERIOD,
    FREE_TRIAL,
    SUBSCRIBED,
    PRE_FREE_TRIAL,
    FREE_TRIAL_WARNING,
    FREE_TRIAL_EXPIRED
} from "../../../utils/consts";
import Isvg from "react-inlinesvg"
import _ from "lodash";
import {buildCapacityObject, getAccountInfoStatus} from "../../../utils/utils";
import {GET_CLUSTERS_AND_ACCOUNT_INFO_QUERY} from "../../../queries";

require("./licenseSettings.scss");

export const LicenseHeader = () => (<div className="license-header">
    <h3>Licensing</h3>
</div>);


const getHeaderText = (accountInfoStatus) => {
    switch (accountInfoStatus.freeTrialStatus) {
        case PRE_FREE_TRIAL: {
            return <span>{`Your ${FREE_TRIAL_PERIOD}-day free trial begins when you set up tiering to your first cluster`}</span>
        }
        case FREE_TRIAL:
        case FREE_TRIAL_WARNING:
            return <span>{`Your ${FREE_TRIAL_PERIOD}-day free trial began when you set up data tiering`}</span>;
        case FREE_TRIAL_EXPIRED:
            if (!(accountInfoStatus.subscriptionStatus === SUBSCRIBED)) {
                return (
                    <div className="header-error">
                        <Isvg cacheGetRequests={true}
                              src={require("../../../assets/svgs/exclamation-mark-triangle-icon.svg")}/>
                        <span>{`Your ${FREE_TRIAL_PERIOD}-day free trial has ended.`}</span>
                    </div>
                )
            }
            return <span></span>;
        default:
            return <span></span>
    }
};

const HeaderItem = ({item: {count, title}}) => {
    return (
        <div className="licensing-header-item">
            <div className="header-item-count">{count}</div>
            <div className="header-item-title">{title}</div>
        </div>
    )
};

const Header = ({headerItems, headerText}) => {
    return (
        <div className="licensing-header">
            <div className="header-counters">{headerItems.map((item, index) => <HeaderItem key={index}
                                                                                           item={item}/>)}</div>
            <div className="header-text">{headerText}</div>
        </div>
    )
};

const ContactUs = () => {
    return (<div className="contact-us">
            <Isvg className="float-center" cacheGetRequests={true} src={require('../../../assets/svgs/envelope.svg')}/>
            <p><a href="mailto:ng-cloud-tiering@netapp.com?subject=Cloud Tiering Service- License Support">Contact us</a> for more info</p>
        </div>
    )
};


class LicenseSettings extends Component {
    render() {
        return (
            <Query query={GET_CLUSTERS_AND_ACCOUNT_INFO_QUERY} fetchPolicy="network-only" pollInterval={30*1000}>
                {({loading, data}) => {
                    if (loading)
                        return (<LoadingIcon text={"Account Information"} icon={<Isvg
                            src={require('../../../assets/svgs/logo.svg')}/>}/>);
                    const {clusters, accountInfo} = data;
                    const accountInfoStatus = getAccountInfoStatus(accountInfo);
                    const totalTiered = buildCapacityObject(_.reduce(clusters, (count, cluster) => count + _.get(cluster, ["tierInformation", "tieredCapacity"], 0), 0));
                    const headerItems = [
                        {count: clusters.length, title: "Clusters"},
                        {count: `${totalTiered.value} ${totalTiered.unit}`, title: "Total Tiered Data"}
                    ];

                    return (<div className="license-settings">
                            <div className="content center">
                                <Header headerItems={accountInfoStatus.freeTrialStatus === PRE_FREE_TRIAL ? [] : headerItems}
                                        headerText={getHeaderText(accountInfoStatus)}/>
                                <Subscribe accountInfoStatus={accountInfoStatus}/>
                                <ContactUs/>
                            </div>
                        </div>
                    );
                }}
            </Query>
        )
    }
}

export default LicenseSettings;