import React, {Component} from 'react'
import {connect} from 'react-redux'
import {Route, Switch} from 'react-router-dom'
import stepinize from "./../wizard/stepinize"
import mapStateToProps from './wizardMapStateToProps'
import Isvg from "react-inlinesvg"
import ButtonWithError from "../widgets/ButtonWithError"
import {reduxForm, SubmissionError} from "redux-form"
import {ClickableDiv} from '../../components/widgets/ClickableDiv'
import classNames from 'classnames'
import {PROVIDERS} from "../../utils/consts"
import {calculateNextStep} from "./WizardStarter";
import _ from "lodash"
import {getNextStepComponent} from "./WizardStarter";
import {GET_CLUSTERS_QUERY} from "../../queries";
import {withApollo} from "react-apollo";
import {extractByType} from "../../utils/utils";

require('./objectStorageProvider.scss');

const ProviderButton = ({type, displayName, handleClick, icon, selected, soon}) => {
    return (<div className={classNames(`${type} provider-card button`, {selected, "soon" : soon, "no-select": !soon && !selected})}>
        {!soon && selected && <ClickableDiv onClick={handleClick}><Isvg className="selected-icon" src={require('./../../assets/svgs/checkmark-fill-circle-icon.svg')}/>
            {icon}
        </ClickableDiv>}
        {!soon && !selected && <div title={`Your cluster is not connected to ${displayName}`}>
            {icon}
        </div>}
        {soon && <div>
            {icon}
            <Isvg className="coming-soon" src={require('./../../assets/svgs/coming-soon.svg')}/>
        </div>}
    </div>)
};


class ObjectStorageProviderStep extends Component {
    constructor(props, context) {
        super(props, context);
        this.state = {};
    }

    componentDidUpdate() {
        const clusterId = _.get(this.props, "routingInfo.urlParams.decodedParams.clusterId", null);
        if (clusterId && !this.state.selectedProvider) {
            const {clusters} = this.props.client.readQuery({query: GET_CLUSTERS_QUERY, variables: {clusterId}});
            const wizardCluster = extractByType(clusters);
            this.setState({selectedProvider: wizardCluster.agentCloudProvider})
        }
    }



    chooseProviderType(provider) {
        this.setState({selectedProvider : provider});
    }

    submit() {
        if (!this.state.selectedProvider) {
            const error = {_error: `In order to continue to the next step please select a provider`};
            throw new SubmissionError(error);
        }

        return Promise.resolve(true)
            .then(() => {
                const nextStep = calculateNextStep(this.props.wizard);
                this.props.wizard.nextStep(`/${this.state.selectedProvider}/${nextStep}`, this.props.history);
            });
    }
    render() {
        if (!this.state.selectedProvider) return <div></div>;
        const {error, handleSubmit, up} = this.props;
        const isSelected = (provider) => {
            return this.state.selectedProvider === provider;
        };
        return (
            <div className={classNames("provider-step wizard-step", {up, down: !up})}>
                <form onSubmit={handleSubmit(this.submit.bind(this))}>
                    <div className="step-title">
                        <Isvg src={require("./../../assets/svgs/object-storage-provider-icon.svg")}/>
                        <h3>Object Storage Provider</h3>
                    </div>
                    <div className="cards-container">
                        {_.keys(PROVIDERS).map((key) => {
                            const provider = PROVIDERS[key];
                            return <ProviderButton key={provider.type} displayName={provider.name} type={provider.type} handleClick={this.chooseProviderType.bind(this, provider.name)} icon={provider.icon} selected={isSelected(provider.name)} soon={provider.soon}/>
                        })}
                    </div>
                    <div className="wizard-button">
                        <ButtonWithError className="button secondary" type="submit" error={error}>
                            Continue
                        </ButtonWithError>
                    </div>
                </form>
            </div>
        )
    }
}

const nextRoutes = ({match, wizard}) => {
    const nextStep = calculateNextStep(wizard, "Object Storage Provider");
    const NextStepComp = getNextStepComponent(nextStep);
    return (
        <Switch>
            <Route path={`${match.url}/:provider/${nextStep}`} render={(props) => <NextStepComp {...props}/>}/>
        </Switch>
    )
};


const ObjectStorageProviderStepForm= reduxForm({
    form: 'provider'
})(ObjectStorageProviderStep);

export default connect(mapStateToProps)(stepinize(withApollo(ObjectStorageProviderStepForm), {
    name: () => `Object Storage Provider`,
    nextRoutes
}));
