import React, {Component} from 'react';
import {connect} from 'react-redux';
import {Route, Switch} from 'react-router-dom';
import {WIZARD_START_WIZARD} from '../../actions'
import SourceVolumesStep from './SourceVolumesStep'
import mapStateToProps from './wizardMapStateToProps'
import _ from 'lodash';
import IPSpaceStep from "./IPSpaceStep";
import ReviewStep from "./ReviewStep";
import ObjectStorageProviderStep from "./ObjectStorageProviderStep";
import BucketStep from "./BucketStep";

export const calculateNextStep = (wizard, forCurrentStep) => {
    const currentStepIndex = wizard.stepNames.indexOf(forCurrentStep || wizard.currentStep);
    const nextStepName = wizard.stepNames[currentStepIndex + 1];
    // console.log(`%c calculateNextStep currentStep=${wizard.currentStep}, curStepIndex=${currentStepIndex} nextStepName=${nextStepName}`, "font-weight: bold; color: purple");
    return wizard.stepNameToPathName[nextStepName];
};

export const getNextStepComponent = (nextStep) => {
    switch (nextStep) {
        case "volumes": return SourceVolumesStep;
        case "ipspace": return IPSpaceStep;
        case "provider": return ObjectStorageProviderStep;
        case "bucket": return BucketStep;
        case "review": return ReviewStep;
        default: {
            throw new Error(`Unknown step ${nextStep}`);
        }
    }
};


const wizards = {
    steps: {
        tier: ['Source Volumes', 'Cluster Connectivity', 'Object Storage Provider', 'Bucket', 'Review'],
        retier: ["Source Volumes", "Review"]

    },
    stepNameToPathName: {
        tier: {
            'Source Volumes': 'volumes',
            'Cluster Connectivity': 'ipspace',
            'Object Storage Provider': 'provider',
            'Bucket': 'bucket',
            'Review': 'review'
        },
        retier: {
            'Source Volumes': 'volumes',
            'Review': 'review'
        }
    }
};

class WizardStarter extends Component {
    constructor(props, context) {
        super(props, context);
        const {match, wizard, data} = props;
        if (match.isExact || !wizard) {
            const clusterId = props.match.params.clusterId;
            const {wizardType, clusters} = data;
            const wizardCluster = _.find(clusters, {clusterId});
            this.props.startWizard(wizardType, wizardCluster,wizards.steps[wizardType],wizards.stepNameToPathName[wizardType]);
        }
    }


    render() {
        return (
            <Switch>
                {/*Source Volumes Step*/}
                <Route path={`/tier/:clusterId/volumes`} render={(props) => <SourceVolumesStep {...props}/>}/>
                <Route path={`/retier/:clusterId/volumes`} render={(props) => <SourceVolumesStep {...props}/>}/>
            </Switch>
        )
    }
}

const mapDispatchToProps = dispatch => {
    return {
        startWizard: (wizardType, wizardCluster, stepNames, stepNameToPathName) => {
            dispatch({
                type: WIZARD_START_WIZARD,
                payload: {
                    wizardType,
                    wizardCluster,
                    stepNames,
                    stepNameToPathName
                }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(WizardStarter);
