import React, {Component} from 'react';
import Isvg from 'react-inlinesvg';
import classNames from 'classnames';
import {connect} from 'react-redux';
import {Link, withRouter} from 'react-router-dom';
import _ from "lodash";
import {MatchChildWidth} from "./../../utils/directives";
import {decodeAll} from "../../utils/encoders";
import {withApollo} from 'react-apollo'
import {GET_CLUSTERS_QUERY} from "../../queries";
import {extractByType} from "../../utils/utils";
require ('./wizard.scss');

class WizardHeader extends Component {
    constructor(props, context) {
        super(props, context);
        this.state = {};
    }
    componentDidUpdate() {
        const clusterId = _.get(this.props, "routingInfo.urlParams.decodedParams.clusterId", null);
        if (clusterId && !this.state.wizardCluster) {
            const {clusters} = this.props.client.readQuery({query: GET_CLUSTERS_QUERY, variables: {clusterId}});
            const wizardCluster = extractByType(clusters);
            this.setState({wizardCluster})
        }
    }


    render() {
        const wizardCluster = this.state.wizardCluster;
        if (!wizardCluster) return <div></div>
        const {cameFrom} = this.props;
        return (
            <div className={classNames("wizard-header", {hidden: this.props.wizard && this.props.wizard.hideHeader})}>
                <div className="title">
                    Tier Cluster {wizardCluster ? `: ${wizardCluster.name}` : ""}
                </div>
                <WizardSteps {...this.props}></WizardSteps>
                <Link className="close" to={cameFrom ? `${cameFrom}`:`/clusters`}><Isvg cacheGetRequests={true}
                                                                src={require("./../../assets/svgs/x.svg")}></Isvg></Link>
            </div>
        )
    }
}

class WizardSteps extends Component {
    render() {
        if (!this.props.wizard || !this.props.wizard.currentStep) return (<div></div>);
        const {wizard: {stepNames, stepNameToPathName, currentStep}, routing: {location}} = this.props;
        const currentIndex = stepNames.indexOf(currentStep);
        let currentPathSegments = _.dropWhile(location.pathname.split("/"), _.isEmpty);
        currentPathSegments = _.each(currentPathSegments, segment => {
            return decodeAll(segment);
        });
        return (
            <MatchChildWidth component="div" className="steps float-center clearfix">
                {stepNames.map((step, index) => {
                    const history = this.props.history;
                    const pathNameOfCurrentIndex = stepNameToPathName[step];
                    const pathIndexOfCurrentIndex = currentPathSegments.indexOf(pathNameOfCurrentIndex);
                    const goBack = index < currentIndex ? () => {
                        const search = _.without(history.location.search, "down=true");
                        history.push("/" + _.take(currentPathSegments, pathIndexOfCurrentIndex + 1).join("/") + "?down=true" + search)
                    } : undefined;
                    return (<WizardStep goBack={goBack} key={`${step}-${index}`} current={currentIndex === index}
                                        future={currentIndex < index} stepName={step} stepNumber={index}
                                        last={index === (stepNames.length - 1)}
                                        addClass={stepNames.length > 6 ? "narrow" : ""}></WizardStep>)
                })}
            </MatchChildWidth>
        )
    }
}

class WizardStep extends Component {
    render() {
        const {stepName, last, current, future, goBack, addClass} = this.props;
        const classes = classNames(addClass, {
            step: true,
            current,
            future,
        });
        return (
            <div className={classes}>
                <button type="button" className={classNames({disabled: !goBack})} onClick={goBack ? goBack : () => {
                }}>
                    <span className="step-name">{stepName}</span>
                    {current && <div className="active-block"></div>}
                </button>
                {!last && <Isvg cacheGetRequests={true} className="step-divider"
                                src={require("./../../assets/svgs/right-chevron.svg")}></Isvg>}
            </div>
        )
    }
}

const mapStateToProps = state => {
    return {
        wizard: state.wizardReducer.wizard,
        routing: state.router,
        routingInfo: state.appRouting.routingInfo
    };
};

export default withRouter(connect(mapStateToProps)(withApollo(WizardHeader)));