const gql = require('graphql-tag');

export const
    GET_CLUSTERS_QUERY = gql`
    query($clusterId: ID){
        clusters(clusterId: $clusterId) {
            agentId
            clusterId
            agentCloudProvider
            name
            ontapClusterProperties {
                ontapVersion
                clusterAddress
            }
            status {
                status
                message
            }
            capacityInformation {
                usedPerformanceAndTieredCapacity
                performanceCapacity{
                    inactiveCapacity
                    activeCapacity
                    isEstimatedInactiveCapacity
                    usedPerformanceCapacity
                }
            }
            tierInformation {
                bucketName
                providerType
                tieredCapacity
                objectStoreName
                regionName
                tierLevel
                savings
            }
            volumes {
                tieredVolumes
                eligibleVolumes
            }
        }
    }`;

export const GET_CLUSTERS_AND_ACCOUNT_INFO_QUERY = gql`
    query($clusterId: ID){
        clusters(clusterId: $clusterId) {
            agentId
            clusterId
            agentCloudProvider
            name
            ontapClusterProperties {
                ontapVersion
                clusterAddress
            }
            status {
                status
                message
            }
            capacityInformation {
                usedPerformanceAndTieredCapacity
                performanceCapacity{
                    inactiveCapacity
                    activeCapacity
                    isEstimatedInactiveCapacity
                    usedPerformanceCapacity
                }
            }
            tierInformation {
                bucketName
                providerType
                tieredCapacity
                objectStoreName
                regionName
                tierLevel
                savings
            }
            volumes {
                tieredVolumes
                eligibleVolumes
            }
        }
        accountInfo{
            accountId
            subscriptionStatus,
            daysLeftForTrial
        }

    }`;

export const GET_AGENTS_QUERY = gql`
    {
        agents {
            agents {
                agentId
                name
                network
                region
                provider
                subnet
                status
                reason
                creatorUserId
            }
            accountId
        }
    }`;

export const GET_REGIONS_QUERY = gql`
    query($type: CLOUD_PROVIDERS!, $clusterId: ID, $regionCode: String){
        regions(type: $type, clusterId: $clusterId, regionCode: $regionCode){
            region
            regionName
        }
    }`;

export const GET_ACCOUNT_INFO_QUERY = gql`
    {
        accountInfo{
            accountId
            subscriptionStatus,
            daysLeftForTrial
        }
    }`;

export const GET_IP_SPACES_QUERY = gql`
    query($clusterId: ID!){
        ipSpaces(clusterId: $clusterId)
    }`;

export const GET_VOLUMES_QUERY = gql`
    query ($clusterId: ID!) {
        volumes(clusterId: $clusterId){
            name
            svmName
            aggregateName
            capacity
            usedPerformanceAndTieredCapacity
            inactiveCapacity
            inactiveCapacityPercent
            tieredCapacity
            tieringPolicy
            isEligibleForTiering
            tieringRestrictionReason
            isEstimatedInactiveCapacity
        }
    }
`;

export const START_TIERING = gql`
    mutation (
                $clusterId: ID!, 
                $volumeIdentifiers: [VolumeIdentifier!]!, 
                $providerProperties: ProviderProperties!, 
                $tieringPolicy: INPUT_TIERING_POLICY,
                $ipSpace: String!) {
        startTiering(input : {clusterId: $clusterId, volumeIdentifiers: $volumeIdentifiers, 
            providerProperties: $providerProperties, tieringPolicy: $tieringPolicy, ipSpace: $ipSpace}) {
            status
        }
    }
`;

export const ADD_TO_TIER = gql`
    mutation ($clusterId: ID!, $volumeIdentifiers: [VolumeIdentifier!]!, $tieringPolicy: INPUT_TIERING_POLICY) {
        addToTier(input : {clusterId: $clusterId, volumeIdentifiers: $volumeIdentifiers, tieringPolicy: $tieringPolicy}) {
            status
        }
    }
`;

export const POST_DISCOVER = gql`
    mutation ($clusterAddress: IpAddress!, $clusterUsername: String!, $clusterPassword: String!, $agentId: String!) {
        discover( input: {
            clusterAddress: $clusterAddress
            clusterUserName: $clusterUsername
            clusterPassword: $clusterPassword
            agentId: $agentId
        }

        ) { clusterId}
    }
`;
